@@ -113,7 +113,12 @@ class Data_inegrator:
                 epoch += 1
                 # Do an epoch on the training set.
                 for patient_train_batch in self.xy_train_dataloader:
-                    field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch['FIELD1'].squeeze()
+                    field0_batch, field1_batch = patient_train_batch['FIELD0'], patient_train_batch['FIELD1']
+                    # If for some reason the batch has mor dimensions than expected, squeeze it.
+                    if len(field0_batch.shape > 2):
+                        field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch[
+                            'FIELD1'].squeeze()
+
                     train_step_function(field0_batch, field1_batch)
 
                 # Do validation
@@ -121,14 +126,15 @@ class Data_inegrator:
                 with torch.no_grad():
                     full_vae.eval()
                     for validation_patient_batch in self.xy_validation_dataloader:
-                        field0_batch, field1_batch = validation_patient_batch['FIELD0'].squeeze(), validation_patient_batch[
-                            'FIELD1'].squeeze()
+                        field0_batch, field1_batch = validation_patient_batch['FIELD0'].squeeze(), \
+                                                     validation_patient_batch[
+                                                         'FIELD1'].squeeze()
                         forward_dict = full_vae(field0_batch, field1_batch)
                         # Computes reconstruction loss and according to it decide whether to stop.
                         loss_dict = full_vae.loss_function(forward_dict)
                         total_validation_loss_per_epoch += float(loss_dict['xvae_loss']['Reconstruction_Loss'] + \
-                                                           loss_dict['xyvae_loss']['Reconstruction_Loss'] + \
-                                                           loss_dict['yvae_loss']['Reconstruction_Loss'])
+                                                                 loss_dict['xyvae_loss']['Reconstruction_Loss'] + \
+                                                                 loss_dict['yvae_loss']['Reconstruction_Loss'])
                     # Compute the average validation sample loss.
                     average_validation_sample_loss = total_validation_loss_per_epoch / len(self.xy_validation_dataset)
                     # If the loss achieved on the validation is the smallest until so far, save the model.
@@ -147,7 +153,6 @@ class Data_inegrator:
         configuration_results_df = configuration_results_df.assign(best_loss=best_results_of_each_configuration)
         configuration_results_df.to_csv(os.path.join(self.results_path, 'models_results.csv'))
 
-
     def project_all_data(self):
         latent_representation_list = []
         patient_id_list = []
